aboutsummaryrefslogtreecommitdiff
path: root/kernel/head.S
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/head.S')
-rw-r--r--kernel/head.S4
1 files changed, 2 insertions, 2 deletions
diff --git a/kernel/head.S b/kernel/head.S
index ac69967..74f83d8 100644
--- a/kernel/head.S
+++ b/kernel/head.S
@@ -27,9 +27,9 @@ _start:
// Ensure alignment for the next double word.
.balign 8
// Load offset. Note that this matches the PAGE_OFFSET as defined in
// `include/mm.h`.
- .dword 0x200000
+ .dword LOAD_BASE_OFFSET
// Size of the image. This is *mandatory* as per bootloader request.
.dword _end - _start
@@ -27,9 +27,9 @@ _start:
// Ensure alignment for the next double word.
.balign 8
- // Load offset. Note that this matches the PAGE_OFFSET as defined in
+ // Load offset. Note that this matches the LOAD_BASE_OFFSET as defined in
// `include/mm.h`.